package com.zbf.system.mapper;

import java.util.List;

import com.baomidou.mybatisplus.core.mapper.BaseMapper; //添加
import com.zbf.system.domain.TCallNoticeOrder;

/**
 * 【请填写功能名称】Mapper接口
 *
 * @author tony
 * @date 2024-07-30
 */
public interface TCallNoticeOrderMapper extends BaseMapper<TCallNoticeOrder> //修改
{
    /**
     * 查询【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public TCallNoticeOrder selectTCallNoticeOrderById(String id);

    /**
     * 查询【请填写功能名称】列表
     *
     * @param tCallNoticeOrder 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<TCallNoticeOrder> selectTCallNoticeOrderList(TCallNoticeOrder tCallNoticeOrder);

    /**
     * 新增【请填写功能名称】
     *
     * @param tCallNoticeOrder 【请填写功能名称】
     * @return 结果
     */
    public int insertTCallNoticeOrder(TCallNoticeOrder tCallNoticeOrder);

    /**
     * 修改【请填写功能名称】
     *
     * @param tCallNoticeOrder 【请填写功能名称】
     * @return 结果
     */
    public int updateTCallNoticeOrder(TCallNoticeOrder tCallNoticeOrder);

    /**
     * 删除【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteTCallNoticeOrderById(String id);

    /**
     * 批量删除【请填写功能名称】
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTCallNoticeOrderByIds(String[] ids);

    /**
     * 批量启用【请填写功能名称】
     *
     * @param ids 需要启用的数据主键集合
     * @return 结果
     */
    public int enableTCallNoticeOrderByIds(String[] ids);

    /**
     * 批量禁用【请填写功能名称】
     *
     * @param ids 需要禁用的数据主键集合
     * @return 结果
     */
    public int disabledTCallNoticeOrderByIds(String[] ids);

    /**
     * 更新状态
     * @param tCallNoticeOrder
     * @return
     */
    public int updateTaskStatus(TCallNoticeOrder tCallNoticeOrder);

}
